==> skawa_components-1.1.0.tar.gz: test/ckeditor_test.dart <==
@TestOn('browser')
import 'dart:convert' show htmlEscape;
import 'package:angular/angular.dart';
import 'package:angular_test/angular_test.dart';
import 'package:skawa_components/ckeditor/ckeditor.dart';
import 'package:test/test.dart';
import 'package:html_unescape/html_unescape.dart';

import 'ckeditor_test.template.dart' as ng;

void main() {
  ng.initReflector();
  tearDown(disposeAnyRunningTest);
  test('CKEditor', () async {
    var bed = NgTestBed<TestEditorComponent>();
    var fixture = await bed.create();
    await fixture.update();
    expect(fixture.assertOnlyInstance.editor.editorName, "editor");
    expect(fixture.assertOnlyInstance.editor.extraPlugins, allOf(isList, hasLength(1)));
    expect(fixture.assertOnlyInstance.editor.extraPlugins.first, predicate((ExtraPlugin plugin) {
      return plugin.path == '/plugin' && plugin.name == 'some-plugin' && plugin.entrypoint == 'plugin.js';
    }));
    expect(fixture.assertOnlyInstance.editor.configUrl, '/some-url');
    expect(HtmlUnescape().convert(fixture.assertOnlyInstance.editor.value), TestEditorComponent._TEST_MARKUP);
  }, skip: "Currently the js bridge is broken");
}

@Component(selector: 'dummy-cke', template: '''
  <skawa-ckeditor editorName="editor" 
                  [extraPlugins]="plugins" 
                  configUrl="/dartlogo/config.js" 
                  [content]="escaped">
  </skawa-ckeditor>
  ''', directives: [SkawaCkeditorComponent])
class TestEditorComponent {
  List<ExtraPlugin> plugins = [ExtraPlugin('dartlogo', '/ckeditor/dartlogo/plugin.js', '')];

  @ViewChild(SkawaCkeditorComponent)
  SkawaCkeditorComponent editor;

  String get escaped => htmlEscape.convert(_TEST_MARKUP);

  static const String _TEST_MARKUP = 'Some <br /> content <p>comes here.</p>';
}

==> skawa_components-1.3.1.tar.gz: test/ckeditor_test.dart <==
@TestOn('browser')
import 'dart:convert' show htmlEscape;
import 'package:angular/angular.dart';
import 'package:angular_test/angular_test.dart';
import 'package:skawa_components/ckeditor/ckeditor.dart';
import 'package:test/test.dart';
import 'package:html_unescape/html_unescape.dart';

import 'ckeditor_test.template.dart' as ng;

void main() {
  ng.initReflector();
  tearDown(disposeAnyRunningTest);
  test('CKEditor', () async {
    var bed = NgTestBed<TestEditorComponent>();
    var fixture = await bed.create();
    await fixture.update();
    expect(fixture.assertOnlyInstance.editor.editorName, "editor");
    expect(fixture.assertOnlyInstance.editor.extraPlugins, allOf(isList, hasLength(1)));
    expect(fixture.assertOnlyInstance.editor.extraPlugins.first, predicate((ExtraPlugin plugin) {
      return plugin.path == '/ckeditor/dartlogo/plugin.js' && plugin.name == 'dartlogo' && plugin.entrypoint == '';
    }));
    expect(fixture.assertOnlyInstance.editor.configUrl, '/dartlogo/config.js');
    expect(HtmlUnescape().convert(fixture.assertOnlyInstance.editor.value), TestEditorComponent._TEST_MARKUP);
  });
}

@Component(selector: 'dummy-cke', template: '''
  <skawa-ckeditor editorName="editor" 
                  [extraPlugins]="plugins" 
                  configUrl="/dartlogo/config.js" 
                  [content]="escaped">
  </skawa-ckeditor>
  ''', directives: [SkawaCkeditorComponent])
class TestEditorComponent {
  List<ExtraPlugin> plugins = [ExtraPlugin('dartlogo', '/ckeditor/dartlogo/plugin.js', '')];

  @ViewChild(SkawaCkeditorComponent)
  SkawaCkeditorComponent editor;

  String get escaped => htmlEscape.convert(_TEST_MARKUP);

  static const String _TEST_MARKUP = 'Some <br /> content <p>comes here.</p>';
}
